##----------------------------------------------------------------------------#
## Copyright (C) 2004  Payam Moghaddam

## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##----------------------------------------------------------------------------#

from pygame.locals import *
import pygame
import os
import GFX
import Ship

def init():
    global screen, background, emptybackground, gfx, playscreen, player1, player2
    
    screen = GFX.screen
    background = GFX.background
    emptybackground = GFX.emptybackground
    screen.blit(background, (0, 0))
    gfx = GFX.gfx
    playscreen = Rect (10, 0, 800, 600)
    player1 = Player(1, (playscreen.right - 120, playscreen.bottom + 10), (playscreen.right - 30, playscreen.bottom + 10), 'player1')
    player2 = Player(2, (playscreen.left + 120, playscreen.bottom + 10), (playscreen.left + 30, playscreen.bottom + 10), 'player2')   
    

class Lifebar(pygame.sprite.Sprite):

    def __init__ (self, player):
        pygame.sprite.Sprite.__init__ (self)
        self.image = pygame.Surface((10,600)).convert()
        self.rect = self.image.get_rect()
        if player == 1:
            self.image = gfx['lifebar1']
            self.rect.topleft = (810,0)
        else:
            self.image = gfx['lifebar2']
            self.rect.topleft = screen.get_rect().topleft
        self.player = player
        self.health = 10
        self.y = 0
        background.blit(self.image, self.rect)
        screen.blit(self.image, self.rect)
        self.empty = gfx['emptybar']

    def change(self, number):
        if number > 0:
            background.blit(self.empty, (self.rect.left,self.y), Rect(0,self.y,10,60))
            screen.blit(self.empty, (self.rect.left,self.y), Rect(0,self.y,10,60))
            self.y += 60
            self.health -= 1
        elif number < 0:
            self.y -= 60
            background.blit(self.image, (self.rect.left,self.y), Rect(0,self.y,10,60))
            screen.blit(self.image, (self.rect.left,self.y), Rect(0,self.y,10,60))
            self.health += 1
        if self.health == 0:
            if self.player == 1:
                Ship.ship1.kill()
            else:
                Ship.ship2.kill()


class Menu(pygame.sprite.Sprite):                    ##Bullets Class##
    #The bullets what will be shot

    def __init__ (self):
        pygame.sprite.Sprite.__init__ (self)
        self.image = gfx['menu']
        self.rect  = self.image.get_rect()
	self.rect.center = GFX.playarea.center
        self.add(GFX.weaponmenu)

class Pointer(pygame.sprite.Sprite):
    def __init__ (self):
        pygame.sprite.Sprite.__init__ (self)
        self.image = gfx['pointer']
        self.rect  = self.image.get_rect()
        self.add(GFX.weaponmenu)
        self.stop = 0
        self.move = 0
        self.position = 1

    def update(self):
        screen.blit(background, self.rect, self.rect)
        if not self.stop:
            if self.move == 1 and self.position != 8:
                self.rect.move_ip (0,45)
                self.position += 1
            elif self.move == 2 and self.position != 1:
                self.rect.move_ip (0,-45)
                self.position -= 1
            self.move = 0

    def decide(self):
        if self.position == 1:
            if player1.life.health < 10:
                if player1.money.number >= 300:
                    player1.updateLife(-1)
                    player1.updateMoney(-300) 
        elif self.position == 2:
            if player1.money.number >= 400:
                Ship.ship1.bullettype = 1
                player1.updateMoney(-400)
        elif self.position == 3:
            if player1.money.number >= 600:
                Ship.ship1.bullettype = 2
                player1.updateMoney(-600)
        elif self.position == 5:
            if player1.money.number >= 900:
                Ship.ship1.bullettype = 3
                player1.updateMoney(-900)
        elif self.position == 6:
            if player1.money.number >= 1400:
                Ship.ship1.bullettype = 4
                player1.updateMoney(-1400)
            
            
    
    def movedown(self): self.move = 1
    def moveup(self): self.move = 2
    


class Messages(pygame.sprite.Sprite):
    def __init__ (self, saying, number, temporary, centerx, centery, fontsize, name):
        pygame.sprite.Sprite.__init__ (self)
        self.area = playscreen
        self.font = pygame.font.Font(None, fontsize)
        self.name = name
        self.saying = saying
        self.number = number
        self.image = self.font.render (('%s %i' % (saying, number)), 1, (255, 255, 255))
        self.rect = self.image.get_rect()
        self.rect.center = playscreen.center
        self.center = playscreen.center
        if centerx != 0 and centery != 0:
            self.rect.centerx = centerx
            self.rect.centery = centery
            self.center = (centerx, centery)
        self.temporary = temporary
        if temporary:
            background.blit(self.image, self.rect)
        screen.blit(self.image, self.rect)

    def update(self):
        screen.blit(background, self.rect, self.rect)
        self.image = self.font.render (('%s %i' % (self.saying, self.number)), 1, (255, 255, 255))
        self.rect = self.image.get_rect()
        self.rect.center = self.center
        if self.temporary:
            background.blit(self.image, self.rect)
        screen.blit(self.image, self.rect)
        
    def remove(self):
        background.blit(emptybackground, self.rect, self.rect)
        screen.blit(background, self.rect, self.rect)


class Player:

    def __init__ (self, ship, scorepos, moneypos, name):
        self.score = Messages('Score:', 0, 0, scorepos[0], scorepos[1], 20, name)
        self.money = Messages('Money:', 0, 0, moneypos[0], moneypos[1], 20, name)
        self.life = Lifebar(ship)

    def updateScore(self, amount):
        self.score.number += amount
        self.score.update()

    def updateMoney(self, amount):
        self.money.number += amount
        self.money.update()

    def updateLife(self, amount):
        self.life.change(amount)
 
