##----------------------------------------------------------------------------#
## Copyright (C) 2004  Payam Moghaddam

## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##----------------------------------------------------------------------------#

import pygame
import GFX
import Weapons
from pygame.locals import Rect
import Features

def init():
    global screen, background, gfx, playscreen, enemylist, ship1, ship2
    global bulletlist, enemysprites, bulletsprites, sfx
    screen = GFX.screen
    background = GFX.background
    gfx = GFX.gfx
    sfx = GFX.sfx
    enemylist = GFX.enemylist
    enemysprites = GFX.enemysprites
    bulletlist = GFX.bulletlist
    bulletsprites = GFX.bulletsprites
    playscreen = Rect (10, 0, 800, 600)
    ship1 = Ships(playscreen.centerx + 60, 810, 'ship1', 'redship')
    ship2 = Ships(playscreen.centerx - 60, 0, 'ship2', 'blueship')
    
class Ships(pygame.sprite.Sprite):

    def __init__ (self, centerx, healthpos, name, image):
        pygame.sprite.Sprite.__init__ (self)
        self.image = gfx[image]
        self.name = name
        self.rect  = self.image.get_rect()
        self.rect.centerx = centerx
        self.area = GFX.playarea
        self.rect.centery = 500
        self.speed = 5
        self.add(GFX.playersprites)
        self.horiz = 0
        self.vertic = 0
        self.health = 10
        self.rotate = 0
        self.shootrate = 0.1
        self.shootspeed = -7
        self.healthypos = 0
        self.healthxpos = healthpos
        self.bullettype = 0
        
    def update(self):
        screen.blit(background, self.rect, self.rect)
        newpos = self.rect
        if self.horiz == 1 and self.vertic == 0:
            newpos = self.rect.move (-self.speed, 0)
        elif self.horiz == 2 and self.vertic == 0:
            newpos = self.rect.move (self.speed, 0)
        elif self.vertic == 1 and self.horiz == 0:
            newpos = self.rect.move (0, -self.speed)
        elif self.vertic == 2 and self.horiz == 0:
            newpos = self.rect.move (0, self.speed)
        elif self.horiz == 1 and self.vertic == 1:
            newpos = self.rect.move (-self.speed, -self.speed)
        elif self.horiz == 2 and self.vertic == 2:
            newpos = self.rect.move (self.speed, self.speed)
        elif self.vertic == 1 and self.horiz == 2:
            newpos = self.rect.move (self.speed, -self.speed)
        elif self.vertic == 2 and self.horiz == 1:
            newpos = self.rect.move (-self.speed, self.speed)
        if self.area.contains(newpos):
                self.rect = newpos
        if pygame.sprite.spritecollide (self, enemysprites, 0):
                enemyhit = pygame.sprite.spritecollide (self, enemysprites, 0)
                for enemies in enemyhit:
                    enemies.hit(self.name, 9)
                    self.hit()
        self.horiz = 0
        self.vertic = 0

    def moveleft(self): self.horiz = 1
    def moveright(self): self.horiz = 2
    def moveup(self): self.vertic = 1
    def movedown(self): self.vertic = 2

    def hit(self):
        if self.name == 'ship1': Features.player1.updateLife(1)
        else: Features.player2.updateLife(1)

    def spin(self):
        self.image = pygame.transform.rotate(self.image, 180)
        if not self.rotate: self.rotate = 1
        else: self.rotate = 0
        self.shootspeed = - self.shootspeed
            
    def shoot(self):
        try:
            if self.rotate:
                shoot(1, self.rect.center, self.bullettype, self.name)
            else:
                shoot(-1, self.rect.center, self.bullettype, self.name)
        except IndexError:
            Bullets()
        #sfx['bullet'].play()


def shoot(direction, center, type, name):
    if type in [1,2,4]: 
        number = 0
        rotation  = -3
        for x in range(3):
            bulletlist[0].shoot(rotation, direction, center, type, name, number)
            number += 1
            rotation += 2
    if type == 3:
        number = -20
        for x in range(3):
            bulletlist[0].shoot(0, direction, (center[0]+number, center[-1]+(0.5*abs(number))), type, name)
            number += 20
    else:
        bulletlist[0].shoot(0, direction, center, type, name, 0)



class Bullets(pygame.sprite.Sprite):                    ##Bullets Class##
    #The bullets what will be shot

    def __init__ (self):
        pygame.sprite.Sprite.__init__ (self)
        self.image  = GFX.gfx['bullet']
        self.name = 'None'
        self.rect  = self.image.get_rect()
	self.area = GFX.playarea
        self.stop = 1
        bulletlist.append(self)
        self.damage = 1
        self.type = 0
        self.x = 0
        self.y = 0
        self.rotate = 0
        

    def shoot(self, rotation, direction, center, type, name, group=0, x=-2, y=0):
        if self.type != type:
            if type == 1: self.image = gfx['bullet1']
            elif type == 2: self.image = gfx['bullet3']
            elif type == 3: self.image = gfx['bullet2']
            elif type == 4: self.image = gfx['bullet4']
            else: self.image = gfx['bullet']
            self.rotate = 0
            self.rect = self.image.get_rect()
            self.type = type
        self.x, self.y = x, y
        self.group = group
        self.name = name
        self.direction = direction
        if direction == 1:
            if not self.rotate:
                self.image = pygame.transform.rotate(self.image, 180)
                self.rotate = 1
        elif direction == -1:
            if self.rotate:
                self.image = pygame.transform.rotate(self.image, 180)
                self.rotate = 0
        self.rotation = rotation
        bulletlist.remove (self)
        self.add (GFX.bulletsprites)
        self.rect.center = center
        self.stop = 0
            
    def update(self):                           
        if self.stop == 0:
            screen.blit(background, self.rect, self.rect)
            self.x, self.y, self.rect.center = Weapons.weapons(self.rect, self.type, self.rotation, self.direction, self.group, self.x, self.y) 
            if pygame.sprite.spritecollide (self, enemysprites, 0):
                enemyhit = pygame.sprite.spritecollide (self, enemysprites, 0)
                for enemies in enemyhit:
                    enemies.hit(self.name, self.damage)
                self.hit()
                
            elif self.rect.top < self.area.top or self.rect.bottom > self.area.bottom:
                self.hit()

    def hit(self):
        self.kill()
        self.stop = 1
        bulletsprites.remove (self)
        bulletlist.append (self)
